"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logout = exports.login = exports.register = exports.loadUser = void 0;
const errors_1 = require("../utils/errors");
const user_record_1 = require("../records/user.record");
// @desc Load user
// @route GET /auth
// @access Private
const loadUser = async (req, res) => {
    if (!req.session.user) {
        throw new errors_1.AuthError();
    }
    const { username, email, createdAt } = req.session.user;
    const loadUserResponseData = { username, email, createdAt };
    res.status(200).json({ user: loadUserResponseData });
};
exports.loadUser = loadUser;
// @desc Register user
// @route POST /auth/register
// @access Public
const register = async (req, res) => {
    let user = new user_record_1.UserRecord(req.body);
    user = await user.create();
    const token = user.getSignedJWTToken();
    req.session.token = token;
    req.session.user = user;
    res.status(200).json({ message: 'User logged in', token });
};
exports.register = register;
// @desc Login user
// @route POST /auth/login
// @access Public
const login = async (req, res) => {
    const { email, password } = req.body;
    if (!email || !password) {
        throw new errors_1.ValidationError('Email and password must be provided');
    }
    if (typeof email !== 'string' || typeof password !== 'string') {
        throw new errors_1.ValidationError('Email and password must be of type string');
    }
    const user = await user_record_1.UserRecord.findOneByEmail(email);
    if (!user) {
        throw new errors_1.ValidationError('User not found');
    }
    const isPasswordCorrect = await user.matchPassword(password);
    if (!isPasswordCorrect) {
        throw new errors_1.ValidationError('Incorrect password');
    }
    const token = user.getSignedJWTToken();
    req.session.token = token;
    req.session.user = user;
    res.status(200).json({ message: 'User logged in', token });
};
exports.login = login;
// @desc Logout user
// @route GET /auth/logout
// @access Public
const logout = async (req, res) => {
    req.session.token = null;
    req.session.user = null;
    res.status(200).json({ message: 'User logged out' });
};
exports.logout = logout;
//# sourceMappingURL=auth.js.map