"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const express_1 = __importStar(require("express"));
const dotenv = __importStar(require("dotenv"));
const cors_1 = __importDefault(require("cors"));
const helmet_1 = __importDefault(require("helmet"));
const hpp_1 = __importDefault(require("hpp"));
const express_rate_limit_1 = __importDefault(require("express-rate-limit"));
const express_session_1 = __importDefault(require("express-session"));
require("express-async-errors");
const errors_1 = require("./utils/errors");
const bookmarks_1 = require("./routes/bookmarks");
const auth_1 = require("./routes/auth");
dotenv.config({ path: './config/config.env' });
const APP_PORT = (process.env.APP_PORT && parseInt(process.env.APP_PORT, 10)) || 3001;
const APP_URL = (process.env.APP_URL && parseInt(process.env.APP_URL, 10)) || 'http://localhost:3001';
const FRONTEND_APP_URL = process.env.FRONTEND_APP_URL || 'http://localhost:3000';
const SESSION_SECRET = process.env.SESSION_SECRET || 'random-string';
const SESSION_EXPIRE = process.env.SESSION_EXPIRE || 2592000000;
const app = (0, express_1.default)();
const appRouter = (0, express_1.Router)();
app.use(express_1.default.json());
app.use((0, helmet_1.default)());
app.use((0, hpp_1.default)());
app.use((0, express_session_1.default)({
    name: 'session',
    secret: SESSION_SECRET,
    resave: false,
    saveUninitialized: false,
    cookie: {
        expires: new Date(Date.now() + Number(SESSION_EXPIRE)),
    },
}));
app.use((0, cors_1.default)({
    origin: FRONTEND_APP_URL,
    credentials: true,
}));
app.use((0, express_rate_limit_1.default)({
    windowMs: 5 * 60 * 1000,
    max: 200,
}));
appRouter.use(express_1.default.static(path_1.default.join(__dirname, 'public')));
appRouter.use('/bookmarks', bookmarks_1.bookmarksRouter);
appRouter.use('/auth', auth_1.authRouter);
app.use('/api', appRouter);
app.use(errors_1.handleMySQLError);
app.use(errors_1.handleError);
app.listen(APP_PORT, '0.0.0.0', () => {
    console.log(`Server listening on ${APP_URL}`);
});
//# sourceMappingURL=index.js.map