"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.testUserRecord = exports.testUserEntity = void 0;
const user_record_1 = require("../user.record");
const db_1 = require("../../utils/db");
exports.testUserEntity = {
    id: '12345678-1234-1234-1234-123456789abc',
    username: 'test username',
    email: 'user-test@email.com',
    password: '123456',
};
exports.testUserRecord = new user_record_1.UserRecord(exports.testUserEntity);
afterAll(() => {
    db_1.pool.end();
});
describe('UserRecord', () => {
    it('should create UserRecord instance', () => {
        const user = new user_record_1.UserRecord(exports.testUserEntity);
        expect(user.username).toBe(exports.testUserEntity.username);
        expect(user.email).toBe(exports.testUserEntity.email);
        expect(user.password).toBe(exports.testUserEntity.password);
    });
    it('should generate id for UserRecord instance if no id passed', () => {
        const newUserEntity = { ...exports.testUserEntity, id: undefined };
        expect(newUserEntity.id).toBeUndefined();
        const user = new user_record_1.UserRecord(newUserEntity);
        expect(typeof user.id === 'string').toBe(true);
    });
});
describe('UserRecord.findOneById() static', () => {
    beforeAll(async () => {
        await exports.testUserRecord.create();
    });
    afterAll(async () => {
        await exports.testUserRecord.delete();
    });
    it('should return test UserRecord entry for existing test id param', async () => {
        const user = await user_record_1.UserRecord.findOneById(exports.testUserRecord.id);
        expect(typeof user === 'object').toBe(true);
        expect(user?.id).toBe(exports.testUserEntity.id);
        expect(user?.username).toBe(exports.testUserEntity.username);
        expect(user?.email).toBe(exports.testUserEntity.email);
        expect(user?.password.length).toBe(60);
    });
    it('should return null for non existing test id param', async () => {
        const user = await user_record_1.UserRecord.findOneById('------------------------------------');
        expect(user).toBeNull();
    });
});
describe('UserRecord.findOneByEmail() static', () => {
    beforeAll(async () => {
        await exports.testUserRecord.create();
    });
    afterAll(async () => {
        await exports.testUserRecord.delete();
    });
    it('should return test UserRecord entry for existing test email param', async () => {
        const user = await user_record_1.UserRecord.findOneByEmail(exports.testUserRecord.email);
        expect(typeof user === 'object').toBe(true);
        expect(user?.id).toBe(exports.testUserEntity.id);
        expect(user?.username).toBe(exports.testUserEntity.username);
        expect(user?.email).toBe(exports.testUserEntity.email);
        expect(user?.password.length).toBe(60);
    });
    it('should return null for non existing test id param', async () => {
        const user = await user_record_1.UserRecord.findOneByEmail('------------------------------------');
        expect(user).toBeNull();
    });
});
describe('UserRecord.create()', () => {
    afterEach(async () => {
        await exports.testUserRecord.delete();
    });
    it('should return UserRecord', async () => {
        const user = await exports.testUserRecord.create();
        expect(user instanceof user_record_1.UserRecord).toBe(true);
    });
    it('should create BookmarkRecord in db', async () => {
        let user = await user_record_1.UserRecord.findOneById(exports.testUserEntity.id);
        expect(user).toBeNull();
        user = await exports.testUserRecord.create();
        expect(user).toStrictEqual(exports.testUserRecord);
        expect(user.id).toBe(exports.testUserRecord.id);
        expect(user.username).toBe(exports.testUserRecord.username);
        expect(user.email).toBe(exports.testUserRecord.email);
        expect(user.password.length).toBe(60);
        expect(user.createdAt instanceof Date).toBe(true);
    });
});
describe('UserRecord.delete()', () => {
    beforeEach(async () => {
        await exports.testUserRecord.create();
    });
    it('should delete UserRecord with given id in db', async () => {
        expect(await user_record_1.UserRecord.findOneById(exports.testUserEntity.id)).toBeDefined();
        await exports.testUserRecord.delete();
        expect(await user_record_1.UserRecord.findOneById(exports.testUserEntity.id)).toBeNull();
    });
});
//# sourceMappingURL=user.record.spec.js.map