"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const uuid_1 = require("uuid");
const jsonwebtoken_1 = require("jsonwebtoken");
const db_1 = require("../utils/db");
const errors_1 = require("../utils/errors");
const user_1 = require("../utils/user");
class UserRecord {
    id;
    username;
    email;
    password;
    createdAt;
    constructor({ id, username, email, password, createdAt }) {
        if (!username) {
            throw new errors_1.ValidationError('User name is required');
        }
        if (username.length > 20) {
            throw new errors_1.ValidationError('User name cannot be more than 20 characters');
        }
        if (!email) {
            throw new errors_1.ValidationError('User email is required');
        }
        if (username.length > 320) {
            throw new errors_1.ValidationError('User email cannot be more than 320 characters');
        }
        if (!password) {
            throw new errors_1.ValidationError('User password is required');
        }
        if (password.length < 6) {
            throw new errors_1.ValidationError('User password cannot be less than 6 characters');
        }
        if (password.length > 60) {
            throw new errors_1.ValidationError('User password cannot be more than 60 characters');
        }
        this.id = id ?? (0, uuid_1.v4)();
        this.username = username;
        this.email = email;
        this.password = password;
        this.createdAt = createdAt || new Date();
    }
    async create() {
        this.password = await (0, user_1.encryptPassword)(this.password);
        await db_1.pool.execute('INSERT INTO `users`(`id`,`username`,`email`, `password`) VALUES(:id, :username, :email, :password)', {
            ...this,
        });
        return this;
    }
    async delete() {
        await db_1.pool.execute('DELETE FROM `users` WHERE `id` = :id', this);
    }
    async matchPassword(password) {
        const isPasswordCorrect = await (0, user_1.comparePassword)(password, this.password);
        return isPasswordCorrect;
    }
    getSignedJWTToken() {
        const JWTToken = (0, jsonwebtoken_1.sign)({ id: this.id }, process.env.JWT_SECRET, { expiresIn: process.env.JWT_EXPIRE });
        return JWTToken;
    }
    static async findOneById(id) {
        const [results] = (await db_1.pool.execute('SELECT * from `users` WHERE `id` = :id', {
            id,
        }));
        if (!results[0])
            return null;
        return new UserRecord(results[0]);
    }
    static async findOneByEmail(email) {
        const [results] = (await db_1.pool.execute('SELECT * from `users` WHERE `email` = :email', {
            email,
        }));
        if (!results[0])
            return null;
        return new UserRecord(results[0]);
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map